$title	Read the IEO 2007 Appendix A Workbook (reference case) 

$include layout

set	yr /1990,2003,2004,2010,2015,2020,2025,2030/,
	yrmap(n,yr) /2.1990, 3.2003, 4.2004, 5.2010, 6.2015, 7.2020, 8.2025, 9.2030 /;

set droprow(n)/5/, dropcol(n)/10/;

parameter
	a1(*,*)		"Total Energy Consumption by Region, Reference Case (Quadrillion Btu)"
	a2(*,*,*)	"Total Energy Consumption by Region and Fuel, Reference Growth Case, (Quadrillion Btu)",
	a3(*,*)		"Gross Domestic Product (GDP) by Region, Reference Case (Billion 2000 Dollars)"
	a4(*,*)		"Liquids Consumption by Region, Reference Case (Million Barrels per Day)"
	a5(*,*)		"Natural Gas Consumption by Region, Reference Case (Trillion Cubic Feet)"
	a6(*,*)		"Coal Consumption by Region, Reference Case (Million Short Tons)"
	a7(*,*)		"Nuclear Energy Consumption by Region, Reference Case (Billion Kilowatthours)"
	a8(*,*)		"Consumption of Hydroelectricity and Other Renewable Energy by Region, Reference Case (Quadrillion Btu)"
	a9(*,*)		"Net Electricity Consumption by Region, Reference Case (Billion Kilowatthours)"
	a10(*,*)	"Carbon Dioxide Emissions by Region, Reference Case (Million Metric Tons Carbon Dioxide)"
	a11(*,*)	"Carbon Dioxide Emissions from Liquids Use by Region, Reference Case (Million Metric Tons Carbon Dioxide)"
	a12(*,*)	"Carbon Dioxide Emissions from Natural Gas Use by Region, Reference Case (Million Metric Tons Carbon Dioxide)"
	a13(*,*)	"Carbon Dioxide Emissions from Coal Use by Region, Reference Case (Million Metric Tons Carbon Dioxide)"
	a14(*,*)	"Population by Region (Millions)";

$offlisting
$include appendixa.gms
$onlisting

loop(yrmap(nn,yr),

	loop(enmap(n,r,en),
	  a2(r,en,yr) = ws2(n,nn); ws2(n,nn) = 0;
	);

	loop(rgmap(n,r),
	  a1(r,yr) = ws1(n,nn); ws1(n,nn) = 0;
	  a3(r,yr) = ws3(n,nn); ws3(n,nn) = 0;
	  a4(r,yr) = ws4(n,nn); ws4(n,nn) = 0;
	  a5(r,yr) = ws5(n,nn); ws5(n,nn) = 0;
	  a6(r,yr) = ws6(n,nn); ws6(n,nn) = 0;
	  a7(r,yr) = ws7(n,nn); ws7(n,nn) = 0;
	  a8(r,yr) = ws8(n,nn); ws8(n,nn) = 0;
	  a9(r,yr) = ws9(n,nn); ws9(n,nn) = 0;
	  a10(r,yr) = ws10(n,nn); ws10(n,nn) = 0;
	  a11(r,yr) = ws11(n,nn); ws11(n,nn) = 0;
	  a12(r,yr) = ws12(n,nn); ws12(n,nn) = 0;
	  a13(r,yr) = ws13(n,nn); ws13(n,nn) = 0;
	  a14(r,yr) = ws14(n,nn); ws14(n,nn) = 0;
	);
);

ws1(droprow,n) = 0; ws1(n,dropcol) = 0;	abort$card(ws1)	"Nonzeros were not all processed in ws1",ws1;
ws2(droprow,n) = 0; ws2(n,dropcol) = 0;	abort$card(ws2)	"Nonzeros were not all processed in ws2",ws2;
ws3(droprow,n) = 0; ws3(n,dropcol) = 0;	abort$card(ws3)	"Nonzeros were not all processed in ws3",ws3;
ws4(droprow,n) = 0; ws4(n,dropcol) = 0;	abort$card(ws4)	"Nonzeros were not all processed in ws4",ws4;
ws5(droprow,n) = 0; ws5(n,dropcol) = 0;	abort$card(ws5)	"Nonzeros were not all processed in ws5",ws5;
ws6(droprow,n) = 0; ws6(n,dropcol) = 0;	abort$card(ws6)	"Nonzeros were not all processed in ws6",ws6;
ws7(droprow,n) = 0; ws7(n,dropcol) = 0;	abort$card(ws7)	"Nonzeros were not all processed in ws7",ws7;
ws8(droprow,n) = 0; ws8(n,dropcol) = 0;	abort$card(ws8)	"Nonzeros were not all processed in ws8",ws8;
ws9(droprow,n) = 0; ws9(n,dropcol) = 0;	abort$card(ws9)	"Nonzeros were not all processed in ws9",ws9;
ws10(droprow,n) = 0; ws10(n,dropcol) = 0; abort$card(ws10) "Nonzeros were not all processed in ws10",ws10;
ws11(droprow,n) = 0; ws11(n,dropcol) = 0; abort$card(ws11) "Nonzeros were not all processed in ws11",ws11;
ws12(droprow,n) = 0; ws12(n,dropcol) = 0; abort$card(ws12) "Nonzeros were not all processed in ws12",ws12;
ws13(droprow,n) = 0; ws13(n,dropcol) = 0; abort$card(ws13) "Nonzeros were not all processed in ws13",ws13;
ws14(droprow,n) = 0; ws14(n,dropcol) = 0; abort$card(ws14) "Nonzeros were not all processed in ws14",ws14;

*	Perform a geometric extrapolation to produce numbers for 2001 and post-2030: 

$batinclude extrap r a1 a3 a4 a5 a6 a7 a8 a9 a10 a11 a12 a13 a14

set ren(*,*);
ren(r,en) = yes;
$batinclude extrap ren a2

parameter	a(*,r,y)	Reference Growth Path;
a("energy",r,y) = a1(r,y);
a(r,en,y) = a2(r,en,y);
a("gdp",r,y) = a3(r,y);
a("liquids",r,y) = a4(r,y);
a("gas",r,y) = a5(r,y);
a("col",r,y) = a6(r,y);
a("nuc",r,y) = a7(r,y);
a("renew",r,y) = a8(r,y);
a("ele",r,y) = a9(r,y);
a("co2",r,y) = a10(r,y);
a("co2liquids",r,y) = a11(r,y);
a("co2gas",r,y) = a12(r,y);
a("co2col",r,y) = a13(r,y);
a("population",r,y) = a14(r,y);
option a:0:2:1;
display a;
