$title	Read the IEO 2007 Appendix C Workbook (low economic growth case) 

$include layout

set	yr /1990,2003,2004,2010,2015,2020,2025,2030/,
	yrmap(n,yr) /2.1990, 3.2003, 4.2004, 5.2010, 6.2015, 7.2020, 8.2025, 9.2030 /;

set droprow(n)/5/, dropcol(n)/10/;

parameter
	c1(*,*)		"Total Energy Consumption by Region, Low Economic Growth Case (Quadrillion Btu)",
	c2(*,*,*)	"Total Energy Consumption by Region and Fuel, Low Economic Growth Case (Quadrillion Btu)",
	c3(*,*)		"Gross Domestic Product (GDP) by Region, Low Economic Growth Case (Billion 2000 Dollars)",
	c4(*,*)		"Liquids Consumption by Region, Low Economic Growth Case (Million Barrels per Day)",
	c5(*,*)		"Natural Gas Consumption by Region, Low Economic Growth Case (Trillion Cubic Feet)",
	c6(*,*)		"Coal Consumption by Region, Low Economic Growth Case (Million Short Tons)",
	c7(*,*)		"Nuclear Energy Consumption by Region, Low Economic Growth Case (Billion Kilowatthours)",
	c8(*,*)		"Consumption of Hydroelectricity and Other Renewable Energy by Region, Low Economic Growth Case (Quadrillion Btu)"
	c9(*,*)		"Carbon Dioxide Emissions by Region, Low Economic Growth Case (Million Metric Tons Carbon Dioxide)",
	c10(*,*)	"Carbon Dioxide Emissions from Liquids Use by Region, Low Economic Growth Case (Million Metric Tons Carbon Dioxide)",
	c11(*,*)	"Carbon Dioxide Emissions from Natural Gas Use by Region, Low Economic Growth Case (Million Metric Tons Carbon Dioxide)",
	c12(*,*)	"Carbon Dioxide Emissions from Coal Use by Region, Low Economic Growth Case (Million Metric Tons Carbon Dioxide)";
	
$offlisting
$include appendixc.gms
$onlisting

loop(yrmap(nn,yr),

	loop(enmap(n,r,en),
	  c2(r,en,yr) = ws2(n,nn); ws2(n,nn) = 0;
	);

	loop(rgmap(n,r),
	  c1(r,yr) = ws1(n,nn); ws1(n,nn) = 0;
	  c3(r,yr) = ws3(n,nn); ws3(n,nn) = 0;
	  c4(r,yr) = ws4(n,nn); ws4(n,nn) = 0;
	  c5(r,yr) = ws5(n,nn); ws5(n,nn) = 0;
	  c6(r,yr) = ws6(n,nn); ws6(n,nn) = 0;
	  c7(r,yr) = ws7(n,nn); ws7(n,nn) = 0;
	  c8(r,yr) = ws8(n,nn); ws8(n,nn) = 0;
	  c9(r,yr) = ws9(n,nn); ws9(n,nn) = 0;
	  c10(r,yr) = ws10(n,nn); ws10(n,nn) = 0;
	  c11(r,yr) = ws11(n,nn); ws11(n,nn) = 0;
	  c12(r,yr) = ws12(n,nn); ws12(n,nn) = 0;
	);
);

ws1(droprow,n) = 0; ws1(n,dropcol) = 0;	abort$card(ws1)	"Nonzeros were not all processed in ws1",ws1;
ws2(droprow,n) = 0; ws2(n,dropcol) = 0;	abort$card(ws2)	"Nonzeros were not all processed in ws2",ws2;
ws3(droprow,n) = 0; ws3(n,dropcol) = 0;	abort$card(ws3)	"Nonzeros were not all processed in ws3",ws3;
ws4(droprow,n) = 0; ws4(n,dropcol) = 0;	abort$card(ws4)	"Nonzeros were not all processed in ws4",ws4;
ws5(droprow,n) = 0; ws5(n,dropcol) = 0;	abort$card(ws5)	"Nonzeros were not all processed in ws5",ws5;
ws6(droprow,n) = 0; ws6(n,dropcol) = 0;	abort$card(ws6)	"Nonzeros were not all processed in ws6",ws6;
ws7(droprow,n) = 0; ws7(n,dropcol) = 0;	abort$card(ws7)	"Nonzeros were not all processed in ws7",ws7;
ws8(droprow,n) = 0; ws8(n,dropcol) = 0;	abort$card(ws8)	"Nonzeros were not all processed in ws8",ws8;
ws9(droprow,n) = 0; ws9(n,dropcol) = 0;	abort$card(ws9)	"Nonzeros were not all processed in ws9",ws9;
ws10(droprow,n) = 0; ws10(n,dropcol) = 0; abort$card(ws10) "Nonzeros were not all processed in ws10",ws10;
ws11(droprow,n) = 0; ws11(n,dropcol) = 0; abort$card(ws11) "Nonzeros were not all processed in ws11",ws11;
ws12(droprow,n) = 0; ws12(n,dropcol) = 0; abort$card(ws12) "Nonzeros were not all processed in ws12",ws12;

$batinclude extrap r c1 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 

set ren(*,*);
ren(r,en) = yes;
$batinclude extrap ren c2


parameter	c(*,r,y)	Low Economic Growth Path;
c("energy",r,y) = c1(r,y);
c(r,en,y) = c2(r,en,y);
c("gdp",r,y) = c3(r,y);
c("liquids",r,y) = c4(r,y);
c("gas",r,y) = c5(r,y);
c("col",r,y) = c6(r,y);
c("nuc",r,y) = c7(r,y);
c("renew",r,y) = c8(r,y);
c("co2",r,y) = c9(r,y);
c("co2liquids",r,y) = c10(r,y);
c("co2gas",r,y) = c11(r,y);
c("co2col",r,y) = c12(r,y);

option c:0:2:1;
display c;

