$title	Read the IEO 2007 Appendix D Workbook (high oil price case) 

$include layout

set	yr /1990,2003,2004,2010,2015,2020,2025,2030/,
	yrmap(n,yr) /2.1990, 3.2003, 4.2004, 5.2010, 6.2015, 7.2020, 8.2025, 9.2030 /;

set droprow(n)/5/, dropcol(n)/10/;

parameter
	d1(*,*)		"Total Energy Consumption by Region, High Oil Price  Case (Quadrillion Btu)",
	d2(*,*,*)	"Total Energy Consumption by Region and Fuel, High Oil Price  Case (Quadrillion Btu)",
	d3(*,*)		"Gross Domestic Product (GDP) by Region, High Oil Price  Case (Billion 2000 Dollars)",
	d4(*,*)		"Liquids Consumption by Region, High Oil Price  Case (Million Barrels per Day)",
	d5(*,*)		"Natural Gas Consumption by Region, High Oil Price  Case (Trillion Cubic Feet)",
	d6(*,*)		"Coal Consumption by Region, High Oil Price  Case (Million Short Tons)",
	d7(*,*)		"Nuclear Energy Consumption by Region, High Oil Price  Case (Billion Kilowatthours)",
	d8(*,*)		"Consumption of Hydroelectricity and Other Renewable Energy by Region, High Oil Price  Case (Quadrillion Btu)"
	d9(*,*)		"Carbon Dioxide Emissions by Region, High Oil Price  Case (Million Metric Tons Carbon Dioxide)",
	d10(*,*)	"Carbon Dioxide Emissions from Liquids Use by Region, High Oil Price  Case (Million Metric Tons Carbon Dioxide)",
	d11(*,*)	"Carbon Dioxide Emissions from Natural Gas Use by Region, High Oil Price  Case (Million Metric Tons Carbon Dioxide)",
	d12(*,*)	"Carbon Dioxide Emissions from Coal Use by Region, High Oil Price  Case (Million Metric Tons Carbon Dioxide)";
	
$offlisting
$include appendixd.gms
$onlisting

loop(yrmap(nn,yr),

	loop(enmap(n,r,en),
	  d2(r,en,yr) = ws2(n,nn); ws2(n,nn) = 0;
	);

	loop(rgmap(n,r),
	  d1(r,yr) = ws1(n,nn); ws1(n,nn) = 0;
	  d3(r,yr) = ws3(n,nn); ws3(n,nn) = 0;
	  d4(r,yr) = ws4(n,nn); ws4(n,nn) = 0;
	  d5(r,yr) = ws5(n,nn); ws5(n,nn) = 0;
	  d6(r,yr) = ws6(n,nn); ws6(n,nn) = 0;
	  d7(r,yr) = ws7(n,nn); ws7(n,nn) = 0;
	  d8(r,yr) = ws8(n,nn); ws8(n,nn) = 0;
	  d9(r,yr) = ws9(n,nn); ws9(n,nn) = 0;
	  d10(r,yr) = ws10(n,nn); ws10(n,nn) = 0;
	  d11(r,yr) = ws11(n,nn); ws11(n,nn) = 0;
	  d12(r,yr) = ws12(n,nn); ws12(n,nn) = 0;
	);
);

ws1(droprow,n) = 0; ws1(n,dropcol) = 0;	abort$card(ws1)	"Nonzeros were not all processed in ws1",ws1;
ws2(droprow,n) = 0; ws2(n,dropcol) = 0;	abort$card(ws2)	"Nonzeros were not all processed in ws2",ws2;
ws3(droprow,n) = 0; ws3(n,dropcol) = 0;	abort$card(ws3)	"Nonzeros were not all processed in ws3",ws3;
ws4(droprow,n) = 0; ws4(n,dropcol) = 0;	abort$card(ws4)	"Nonzeros were not all processed in ws4",ws4;
ws5(droprow,n) = 0; ws5(n,dropcol) = 0;	abort$card(ws5)	"Nonzeros were not all processed in ws5",ws5;
ws6(droprow,n) = 0; ws6(n,dropcol) = 0;	abort$card(ws6)	"Nonzeros were not all processed in ws6",ws6;
ws7(droprow,n) = 0; ws7(n,dropcol) = 0;	abort$card(ws7)	"Nonzeros were not all processed in ws7",ws7;
ws8(droprow,n) = 0; ws8(n,dropcol) = 0;	abort$card(ws8)	"Nonzeros were not all processed in ws8",ws8;
ws9(droprow,n) = 0; ws9(n,dropcol) = 0;	abort$card(ws9)	"Nonzeros were not all processed in ws9",ws9;
ws10(droprow,n) = 0; ws10(n,dropcol) = 0; abort$card(ws10) "Nonzeros were not all processed in ws10",ws10;
ws11(droprow,n) = 0; ws11(n,dropcol) = 0; abort$card(ws11) "Nonzeros were not all processed in ws11",ws11;
ws12(droprow,n) = 0; ws12(n,dropcol) = 0; abort$card(ws12) "Nonzeros were not all processed in ws12",ws12;

$batinclude extrap r d1 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 

set ren(*,*);
ren(r,en) = yes;
$batinclude extrap ren d2


parameter	d(*,r,y)	High Oil Price Path;
d("energy",r,y) = d1(r,y);
d(r,en,y) = d2(r,en,y);
d("gdp",r,y) = d3(r,y);
d("liquids",r,y) = d4(r,y);
d("gas",r,y) = d5(r,y);
d("col",r,y) = d6(r,y);
d("nuc",r,y) = d7(r,y);
d("renew",r,y) = d8(r,y);
d("co2",r,y) = d9(r,y);
d("co2liquids",r,y) = d10(r,y);
d("co2gas",r,y) = d11(r,y);
d("co2col",r,y) = d12(r,y);

option d:0:2:1;
display d;

